#!/usr/bin/env python3
"""
Entry point for running chunking_strategy as a module.

This allows the package to be run with:
    python -m chunking_strategy
"""

from chunking_strategy.cli import main

if __name__ == "__main__":
    main()
